import { pgTable, uuid, timestamp, index, uniqueIndex } from 'drizzle-orm/pg-core';
import { persons } from './persons';
import { groups } from './groups';

/**
 * Person to Group relation table schema
 */
export const personToGroup = pgTable('person_to_group', {
  id: uuid('id').primaryKey().defaultRandom(),
  personId: uuid('personId').notNull().references(() => persons.id, { onDelete: 'cascade' }),
  groupId: uuid('groupId').notNull().references(() => groups.id, { onDelete: 'cascade' }),
  createdAt: timestamp('createdAt', { withTimezone: true }).defaultNow().notNull()
}, (table) => {
  return {
    personIdIdx: index('ptg_personId_idx').on(table.personId),
    groupIdIdx: index('ptg_groupId_idx').on(table.groupId),
    personGroupUniqueIdx: uniqueIndex('ptg_person_group_unique_idx').on(table.personId, table.groupId)
  };
});

/**
 * PersonToGroup type definitions
 */
export type PersonToGroup = typeof personToGroup.$inferSelect;
export type NewPersonToGroup = typeof personToGroup.$inferInsert;
