import { pgTable, uuid, varchar, text, timestamp, jsonb, index } from 'drizzle-orm/pg-core';
import { DbSchema } from './db-schema';

/**
 * Users table schema
 */
export const users = pgTable('users', {
  id: uuid('id').primaryKey().defaultRandom(), // UUIDv7 for chronological order
  name: varchar('name', { length: 100 }).notNull(),
  avatar: text('avatar'), // URL from Github API
  githubId: varchar('githubId', { length: 50 }).notNull().unique(),
  gdprTimestamp: timestamp('gdprTimestamp', { withTimezone: true }),
  createdAt: timestamp('createdAt', { withTimezone: true }).defaultNow().notNull(),
  updatedAt: timestamp('updatedAt', { withTimezone: true }).defaultNow().notNull(),
  metadata: jsonb('metadata').default({})
}, (table) => {
  return {
    githubIdIdx: index('githubId_idx').on(table.githubId),
    createdAtIdx: index('createdAt_idx').on(table.createdAt)
  };
});

/**
 * User type definitions
 */
export type User = typeof users.$inferSelect;
export type NewUser = typeof users.$inferInsert;