import { 
  IsString, 
  IsOptional, 
  IsObject, 
  IsUUID, 
  IsEnum, 
  IsInt, 
  IsBoolean, 
  Min, 
  Max 
} from 'class-validator';
import { Type } from 'class-transformer';
import { Gender, OralEaseLevel } from './create-person.dto';

/**
 * DTO for updating a person
 */
export class UpdatePersonDto {
  @IsString()
  @IsOptional()
  firstName?: string;

  @IsString()
  @IsOptional()
  lastName?: string;

  @IsEnum(Gender)
  @IsOptional()
  gender?: Gender;

  @IsInt()
  @Min(1)
  @Max(5)
  @IsOptional()
  @Type(() => Number)
  technicalLevel?: number;

  @IsBoolean()
  @IsOptional()
  @Type(() => Boolean)
  hasTechnicalTraining?: boolean;

  @IsInt()
  @Min(1)
  @Max(5)
  @IsOptional()
  @Type(() => Number)
  frenchSpeakingLevel?: number;

  @IsEnum(OralEaseLevel)
  @IsOptional()
  oralEaseLevel?: OralEaseLevel;

  @IsInt()
  @IsOptional()
  @Min(18)
  @Max(100)
  @Type(() => Number)
  age?: number;

  @IsUUID()
  @IsOptional()
  projectId?: string;

  @IsObject()
  @IsOptional()
  attributes?: Record<string, any>;
}